@@ -1660,9 +1660,9 @@ def log_sender_master():
 
 
 def init_sender(config):
-    gevent.signal(signal.SIGINT, sender_shutdown)
-    gevent.signal(signal.SIGTERM, sender_shutdown)
-    gevent.signal(signal.SIGQUIT, sender_shutdown)
+    gevent.signal_handler(signal.SIGINT, sender_shutdown)
+    gevent.signal_handler(signal.SIGTERM, sender_shutdown)
+    gevent.signal_handler(signal.SIGQUIT, sender_shutdown)
 
     process_title = config['sender'].get('process_title')
 
@@ -1670,9 +1670,8 @@ def init_sender(config):
         setproctitle.setproctitle(process_title)
         logger.info('Changing process name to %s', process_title)
 
-    api_host = config['sender'].get('api_host', 'http://localhost:16649')
     db.init(config)
-    cache.init(api_host, config)
+    cache.init(config)
     metrics.init(config, 'iris-sender', default_sender_metrics)
     api_cache.cache_priorities()
     api_cache.cache_applications()
@@ -1695,7 +1694,7 @@ def init_sender(config):
         }]
 
     global quota
-    quota = ApplicationQuota(db, cache.targets_for_role, message_send_enqueue, config['sender'].get('sender_app'))
+    quota = ApplicationQuota(db, cache.targets_for_role, message_send_enqueue, config['sender'].get('sender_app'), config['sender'].get('default_rate_def', {}))
 
     global coordinator
     zk_hosts = config['sender'].get('zookeeper_cluster', False)
